##  Workspace Designs
In the Pre-Defined Designs section on the branding settings page, you can select your workspace design. Any changes that you make are applied immediately and become visible to all workspace users. The following designs are available:
  * SAP LeanIX: This is the default workspace design, which uses the SAP brand color scheme.
  * Classic: This design employs a blue color scheme and was the default design before October 15, 2024.
  * Custom: This option enables you to customize your workspace design. For more information, see [Applying a Custom Design to a Workspace](https://help.sap.com/docs/leanix/ea/branding-settings?locale=en-US&state=PRODUCTION&version=CLOUD#loio275853a97a4410149dc5901b3db648e4__applying_a_custom_design_to_a_workspace).
